==> jaguar_session_mongo-0.0.1.tar.gz: example/common/user.dart <==
library example.common.user;

import 'dart:async';
import 'package:jaguar_auth/jaguar_auth.dart';

class User implements AuthorizationUser {
  final String id;

  final String username;

  final String password;

  const User(this.id, this.username, this.password);

  String get loginId => username;

  String get loginPassword => password;

  String get authorizationId => id;
}

const Map<String, User> kUsers = const {
  '0': const User('0', 'teja', 'word'),
  '1': const User('1', 'kleak', 'pass'),
};

const WhiteListPasswordChecker kModelManager =
    const WhiteListPasswordChecker(kUsers);

/// Model manager to authenticate against a static list of user models
class WhiteListPasswordChecker implements AuthModelManager {
  /// User models to white list
  final Map<String, User> models;

  /// Password hasher
  final Hasher hasher;

  const WhiteListPasswordChecker(Map<String, User> models, {Hasher hasher})
      : models = models ?? const {},
        hasher = hasher ?? const NoHasher();

  Future<User> authenticate(String username, String password) async {
    User model = await fetchModelByAuthenticationId(username);

    if (model == null) {
      return null;
    }

    if (!hasher.verify(password, model.loginPassword)) {
      return null;
    }

    return model;
  }

  Future<User> fetchModelByAuthenticationId(String authName) async =>
      models.values
          .firstWhere((model) => model.loginId == authName, orElse: () => null);

  Future<User> fetchModelByAuthorizationId(String sessionId) async {
    if (!models.containsKey(sessionId)) {
      return null;
    }

    return models[sessionId];
  }
}

==> jaguar_session_mongo-0.0.3.tar.gz: example/common/user.dart <==
library example.common.user;

import 'dart:async';
import 'package:jaguar/jaguar.dart';
import 'package:jaguar_auth/jaguar_auth.dart';

class User implements AuthorizationUser {
  final String id;

  final String username;

  final String password;

  const User(this.id, this.username, this.password);

  String get loginId => username;

  String get loginPassword => password;

  String get authorizationId => id;
}

const Map<String, User> kUsers = const {
  '0': const User('0', 'teja', 'word'),
  '1': const User('1', 'kleak', 'pass'),
};

const WhiteListPasswordChecker kModelManager =
    const WhiteListPasswordChecker(kUsers);

/// Model manager to authenticate against a static list of user models
class WhiteListPasswordChecker implements AuthModelManager {
  /// User models to white list
  final Map<String, User> models;

  /// Password hasher
  final Hasher hasher;

  const WhiteListPasswordChecker(Map<String, User> models, {Hasher hasher})
      : models = models ?? const {},
        hasher = hasher ?? const NoHasher();

  Future<User> authenticate(
      Context ctx, String username, String password) async {
    User model = await fetchModelByAuthenticationId(ctx, username);

    if (model == null) {
      return null;
    }

    if (!hasher.verify(password, model.loginPassword)) {
      return null;
    }

    return model;
  }

  Future<User> fetchModelByAuthenticationId(
          Context ctx, String authName) async =>
      models.values
          .firstWhere((model) => model.loginId == authName, orElse: () => null);

  Future<User> fetchModelByAuthorizationId(
      Context ctx, String sessionId) async {
    if (!models.containsKey(sessionId)) {
      return null;
    }

    return models[sessionId];
  }
}
